#' Save output
#'
#' This function saves data frames and plots generated by EpiCompare.
#'
#' @param save_output Default FALSE. If TRUE, outputs are saved.
#' @param file Tables and plots to be saved.
#' @param file_type Type of file to be saved.
#' "data.frame", "ggplot", "image"
#' @param filename Name of file.
#' @param outpath Outpath
#' @param interactive Default FALSE. If TRUE, interactive plots are saved as
#' html.
#'
#' @importFrom htmltools save_html
#'
#' @return Saved data frames and plots.
#' @keywords internal
#'
save_output <- function(save_output = FALSE,
                        file,
                        file_type,
                        filename,
                        outpath,
                        interactive=FALSE){

  if(save_output){
    if(file_type == "data.frame"){
      data.table::fwrite(x = file,
                         file = paste0(outpath,"/",filename,".txt"),
                         sep = "\t")
    }else if(file_type == "ggplot"){

      if(interactive){
        message("Saving HTML file")
        htmltools::save_html(html = file,
                             file = paste0(outpath,"/",filename,".html"))
      }else{
        ggplot2::ggsave(filename = paste0(filename,".png"),
                        plot = file,
                        device = "png",
                        path = outpath)
        unlink(paste0(filename,".png"))
      }
    }else if(file_type == "image"){
      requireNamespace("grDevices")
      grDevices::png(paste0(outpath,"/",filename,".png"))
      print(file)
      grDevices::dev.off()
    }
  }
}
